@@ -25,7 +25,6 @@
 #ifndef __USER_GROUP_XML_H
 #define __USER_GROUP_XML_H
 
-#include <gnome.h>
 #include "user-settings.h"
 
 gchar    *generic_value_string         (xmlNodePtr node, const gchar *name);
@@ -93,6 +92,7 @@ void		group_update_xml	(xmlNodePtr, gchar*, gchar*, GList*);
 xmlNodePtr	user_add_blank_xml  	(xmlNodePtr);
 void		user_update_xml		(xmlNodePtr, UserAccountData*, gboolean);
 void		del_user_groups		(xmlNodePtr);
+GList*          user_get_groups         (xmlNodePtr);
 
 GList *		get_group_users		(xmlNodePtr);
 GList *		get_list_from_node	(gchar*, gint);
